Crate subsoil

Crate subsoil 

Re-exports

pub extern crate alloc;
pub use subsoil_crypto_hashing as crypto_hashing;

Modules

allocator
Collection of allocator implementations.
api
Substrate runtime api
application_crypto
Traits and macros for constructing application specific strongly typed crypto wrappers.
arithmetic
Minimal fixed point arithmetic primitives and types for runtime.
binary_merkle_tree
This module implements a simple binary Merkle Tree utilities required for inter-op with Ethereum bridge & Solidity contract.
block_builder
The block builder runtime api.
consensus
Consensus engine primitives.
core
Shareable Substrate types.
crypto_ec_utils
This module offers elliptic curves types which are compatible with the Arkworks library functionalities.
database
The main database trait, allowing Substrate to store data persistently.
externalities
Substrate externalities abstraction
genesis_builder
Substrate genesis config builder.
inherents
Substrate Inherent Extrinsics
io
Substrate Primitives: IO
keyring
Support code for the runtime. A set of test accounts.
keystore
Keystore traits
metadata_ir
Intermediate representation of the runtime metadata.
mixnet
Mixnet types and runtime interface.
mmr
Merkle Mountain Range primitive types.
npos_elections
A set of election algorithms to be used with a substrate runtime, typically within the staking sub-system. Notable implementation include:
offchain_worker
The Offchain Worker runtime api primitives.
panic_handler
Custom panic hook with bug report link
runtime
Substrate Runtime Primitives.
runtime_interface
Substrate runtime interface
session
Substrate core types around sessions.
staking
A crate which contains primitives that are useful for implementation that uses staking approaches in general. Definitions related to sessions, slashing, etc go here.
state_machine
Substrate state machine implementation.
std
Lowest-abstraction level for the Substrate runtime: just exports useful primitives from std or client/alloc to be used with any code that depends on the runtime.
storage
Primitive types for storage related stuff.
timestamp
Substrate core types and inherents for timestamps.
tracing
Substrate tracing primitives and macros.
trie
Utility functions to interact with Substrate’s Base-16 Modified Merkle Patricia tree (“trie”).
txpool
Transaction pool runtime facing API.
version
Substrate runtime version
wasm_interface
Types and traits for interfacing between the host and the wasm runtime.
weights
Primitives for transaction weighting.

Macros

_bandersnatch_experimental_enabled
_bls_experimental_enabled
_runtime_benchmarks_enabled
app_crypto
Declares Public, Pair, Signature and ProofOfPossession types which are functionally equivalent to the corresponding types defined by $module but are new application-specific types whose identifier is $key_type.
app_crypto_pair_common
Declares Pair type which is functionally equivalent to $pair, but is new application-specific type whose identifier is $key_type. It is a common part shared between full_crypto and non full_crypto environments.
assert_eq_error_rate
Copied from sp-runtime and documented there.
assert_eq_error_rate_float
Same as [assert_eq_error_rate], but intended to be used with floating point number, or generally those who do not have over/underflow potentials.
assert_eq_uvec
Panic when the vectors are different, without taking the order into account.
capture_test_logs
Macro for capturing logs during test execution.
count
Calls a given macro a number of times with a set of fixed params and an incrementing numeral. e.g.
create_apis_vec
Create a vector of Api declarations.
create_runtime_strDeprecated
Deprecated Cow::Borrowed() wrapper.
decl_extension
Macro for declaring an extension that usable with Extensions.
defer
Executes the given code when the current scope is dropped.
enter_span
Enter a span.
generate_feature_enabled_macro
Generates a macro for checking if a certain feature is enabled.
hex2array
Provides a const array from given string literal.
if_wasmtime_is_enabled
impl_maybe_marker
Macro for creating Maybe* marker traits.
impl_maybe_marker_std_or_serde
Macro for creating Maybe* marker traits.
impl_opaque_keys
Implement OpaqueKeys for a described struct.
impl_tx_ext_default
Helper macro to be used in a impl TransactionExtension block to add default implementations of weight, validate, prepare or any combinations of the them.
map
Initialize a key-value collection from array.
morph_types
Create a Morph and/or TryMorph impls with a simple closure-like expression.
wasm_export_functions
Macro for exporting functions from wasm in with the expected signature for using it with the wasm executor. This is useful for tests where you need to call a function in wasm.
with_pair
Generate the given code if the pair type is available.
within_span
Runs given code within a tracing span, measuring it’s execution time.
wrap
Implement bidirectional From and on-way AsRef/AsMut for two types, $inner and $outer.