macro_rules! assert_eq_uvec {
( $x:expr, $y:expr $(,)? ) => { ... };
}Expand description
Panic when the vectors are different, without taking the order into account.
macro_rules! assert_eq_uvec {
( $x:expr, $y:expr $(,)? ) => { ... };
}Panic when the vectors are different, without taking the order into account.