pub enum Error {
SolutionWeightOverflow,
SolutionTargetOverflow,
SolutionInvalidIndex,
SolutionInvalidPageIndex,
ArithmeticError,
InvalidSupportEdge,
TooManyVoters,
BoundsExceeded,
DuplicateVoter,
DuplicateTarget,
}Expand description
The errors that might occur in this crate and topsoil-election-provider-solution-type.
Variants
SolutionWeightOverflow
While going from solution indices to ratio, the weight of all the edges has gone above the total.
SolutionTargetOverflow
The solution type has a voter who’s number of targets is out of bound.
SolutionInvalidIndex
One of the index functions returned none.
SolutionInvalidPageIndex
One of the page indices was invalid.
ArithmeticError
An error occurred in some arithmetic operation.
InvalidSupportEdge
The data provided to create support map was invalid.
TooManyVoters
The number of voters is bigger than the MaxVoters bound.
BoundsExceeded
Some bounds were exceeded when converting election types.
DuplicateVoter
A duplicate voter was detected.
DuplicateTarget
A duplicate target was detected.