PartialOrd

Trait PartialOrd 

1.0.0 (const: unstable) · Source
pub trait PartialOrd<Rhs = Self>: PartialEq<Rhs>
where Rhs: ?Sized,
{ // Required method fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>; // Provided methods fn lt(&self, other: &Rhs) -> bool { ... } fn le(&self, other: &Rhs) -> bool { ... } fn gt(&self, other: &Rhs) -> bool { ... } fn ge(&self, other: &Rhs) -> bool { ... } }
Trait for types that form a partial order.

The lt, le, gt, and ge methods of this trait can be called using the <, <=, >, and >= operators, respectively.

This trait should only contain the comparison logic for a type if one plans on only implementing PartialOrd but not Ord. Otherwise the comparison logic should be in Ord and this trait implemented with Some(self.cmp(other)).

The methods of this trait must be consistent with each other and with those of PartialEq. The following conditions must hold:

  1. a == b if and only if partial_cmp(a, b) == Some(Equal).
  2. a < b if and only if partial_cmp(a, b) == Some(Less)
  3. a > b if and only if partial_cmp(a, b) == Some(Greater)
  4. a <= b if and only if a < b || a == b
  5. a >= b if and only if a > b || a == b
  6. a != b if and only if !(a == b).

Conditions 2–5 above are ensured by the default implementation. Condition 6 is already ensured by PartialEq.

If Ord is also implemented for Self and Rhs, it must also be consistent with partial_cmp (see the documentation of that trait for the exact requirements). It’s easy to accidentally make them disagree by deriving some of the traits and manually implementing others.

The comparison relations must satisfy the following conditions (for all a, b, c of type A, B, C):

  • Transitivity: if A: PartialOrd<B> and B: PartialOrd<C> and A: PartialOrd<C>, then a < b and b < c implies a < c. The same must hold for both == and >. This must also work for longer chains, such as when A: PartialOrd<B>, B: PartialOrd<C>, C: PartialOrd<D>, and A: PartialOrd<D> all exist.
  • Duality: if A: PartialOrd<B> and B: PartialOrd<A>, then a < b if and only if b > a.

Note that the B: PartialOrd<A> (dual) and A: PartialOrd<C> (transitive) impls are not forced to exist, but these requirements apply whenever they do exist.

Violating these requirements is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Cross-crate considerations

Upholding the requirements stated above can become tricky when one crate implements PartialOrd for a type of another crate (i.e., to allow comparing one of its own types with a type from the standard library). The recommendation is to never implement this trait for a foreign type. In other words, such a crate should do impl PartialOrd<ForeignType> for LocalType, but it should not do impl PartialOrd<LocalType> for ForeignType.

This avoids the problem of transitive chains that criss-cross crate boundaries: for all local types T, you may assume that no other crate will add impls that allow comparing T < U. In other words, if other crates add impls that allow building longer transitive chains U1 < ... < T < V1 < ..., then all the types that appear to the right of T must be types that the crate defining T already knows about. This rules out transitive chains where downstream crates can add new impls that “stitch together” comparisons of foreign types in ways that violate transitivity.

Not having such foreign impls also avoids forward compatibility issues where one crate adding more PartialOrd implementations can cause build failures in downstream crates.

Corollaries

The following corollaries follow from the above requirements:

  • irreflexivity of < and >: !(a < a), !(a > a)
  • transitivity of >: if a > b and b > c then a > c
  • duality of partial_cmp: partial_cmp(a, b) == partial_cmp(b, a).map(Ordering::reverse)

Strict and non-strict partial orders

The < and > operators behave according to a strict partial order. However, <= and >= do not behave according to a non-strict partial order. That is because mathematically, a non-strict partial order would require reflexivity, i.e. a <= a would need to be true for every a. This isn’t always the case for types that implement PartialOrd, for example:

let a = f64::NAN;
assert_eq!(a <= a, false);

Derivable

This trait can be used with #[derive].

When derived on structs, it will produce a lexicographic ordering based on the top-to-bottom declaration order of the struct’s members.

When derived on enums, variants are primarily ordered by their discriminants. Secondarily, they are ordered by their fields. By default, the discriminant is smallest for variants at the top, and largest for variants at the bottom. Here’s an example:

#[derive(PartialEq, PartialOrd)]
enum E {
    Top,
    Bottom,
}

assert!(E::Top < E::Bottom);

However, manually setting the discriminants can override this default behavior:

#[derive(PartialEq, PartialOrd)]
enum E {
    Top = 2,
    Bottom = 1,
}

assert!(E::Bottom < E::Top);

How can I implement PartialOrd?

PartialOrd only requires implementation of the partial_cmp method, with the others generated from default implementations.

However it remains possible to implement the others separately for types which do not have a total order. For example, for floating point numbers, NaN < 0 == false and NaN >= 0 == false (cf. IEEE 754-2008 section 5.11).

PartialOrd requires your type to be PartialEq.

If your type is Ord, you can implement partial_cmp by using cmp:

use std::cmp::Ordering;

struct Person {
    id: u32,
    name: String,
    height: u32,
}

impl PartialOrd for Person {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl Ord for Person {
    fn cmp(&self, other: &Self) -> Ordering {
        self.height.cmp(&other.height)
    }
}

impl PartialEq for Person {
    fn eq(&self, other: &Self) -> bool {
        self.height == other.height
    }
}

impl Eq for Person {}

You may also find it useful to use partial_cmp on your type’s fields. Here is an example of Person types who have a floating-point height field that is the only field to be used for sorting:

use std::cmp::Ordering;

struct Person {
    id: u32,
    name: String,
    height: f64,
}

impl PartialOrd for Person {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        self.height.partial_cmp(&other.height)
    }
}

impl PartialEq for Person {
    fn eq(&self, other: &Self) -> bool {
        self.height == other.height
    }
}

Examples of incorrect PartialOrd implementations

use std::cmp::Ordering;

#[derive(PartialEq, Debug)]
struct Character {
    health: u32,
    experience: u32,
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.health.cmp(&other.health))
    }
}

let a = Character {
    health: 10,
    experience: 5,
};
let b = Character {
    health: 10,
    experience: 77,
};

// Mistake: `PartialEq` and `PartialOrd` disagree with each other.

assert_eq!(a.partial_cmp(&b).unwrap(), Ordering::Equal); // a == b according to `PartialOrd`.
assert_ne!(a, b); // a != b according to `PartialEq`.

Examples

let x: u32 = 0;
let y: u32 = 1;

assert_eq!(x < y, true);
assert_eq!(x.lt(&y), true);

Required Methods

1.0.0 · Source

fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>

This method returns an ordering between self and other values if one exists.

Examples
use std::cmp::Ordering;

let result = 1.0.partial_cmp(&2.0);
assert_eq!(result, Some(Ordering::Less));

let result = 1.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Equal));

let result = 2.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Greater));

When comparison is impossible:

let result = f64::NAN.partial_cmp(&1.0);
assert_eq!(result, None);

Provided Methods

1.0.0 · Source

fn lt(&self, other: &Rhs) -> bool

Tests less than (for self and other) and is used by the < operator.

Examples
assert_eq!(1.0 < 1.0, false);
assert_eq!(1.0 < 2.0, true);
assert_eq!(2.0 < 1.0, false);
1.0.0 · Source

fn le(&self, other: &Rhs) -> bool

Tests less than or equal to (for self and other) and is used by the <= operator.

Examples
assert_eq!(1.0 <= 1.0, true);
assert_eq!(1.0 <= 2.0, true);
assert_eq!(2.0 <= 1.0, false);
1.0.0 · Source

fn gt(&self, other: &Rhs) -> bool

Tests greater than (for self and other) and is used by the > operator.

Examples
assert_eq!(1.0 > 1.0, false);
assert_eq!(1.0 > 2.0, false);
assert_eq!(2.0 > 1.0, true);
1.0.0 · Source

fn ge(&self, other: &Rhs) -> bool

Tests greater than or equal to (for self and other) and is used by the >= operator.

Examples
assert_eq!(1.0 >= 1.0, true);
assert_eq!(1.0 >= 2.0, false);
assert_eq!(2.0 >= 1.0, true);

Implementors

Source

impl PartialOrd for CallContext

Source

impl PartialOrd for subsoil::keyring::ed25519::Keyring

Source

impl PartialOrd for subsoil::keyring::sr25519::Keyring

Source

impl PartialOrd for MultiSigner

Source

impl PartialOrd for ChildInfo

1.34.0 (const: unstable) · Source

impl PartialOrd for Infallible

1.0.0 (const: unstable) · Source

impl PartialOrd for Ordering

Source

impl PartialOrd for AsciiChar

1.7.0 · Source

impl PartialOrd for IpAddr

1.0.0 · Source

impl PartialOrd for SocketAddr

1.0.0 · Source

impl PartialOrd for ErrorKind

Source

impl PartialOrd for Language

Source

impl PartialOrd for byteorder::BigEndian

Source

impl PartialOrd for byteorder::LittleEndian

Source

impl PartialOrd for const_oid::error::Error

Source

impl PartialOrd for SectionId

Source

impl PartialOrd for ColumnType

Source

impl PartialOrd for log::Level

Source

impl PartialOrd for log::LevelFilter

Source

impl PartialOrd for Locale

Source

impl PartialOrd for regex_syntax::utf8::Utf8Sequence

Source

impl PartialOrd for regex_syntax::utf8::Utf8Sequence

Source

impl PartialOrd for MetaForm

Source

impl PartialOrd for PortableForm

Source

impl PartialOrd for TypeDefPrimitive

Source

impl PartialOrd for All

Source

impl PartialOrd for SignOnly

Source

impl PartialOrd for VerifyOnly

Source

impl PartialOrd for ElligatorSwiftParty

Source

impl PartialOrd for secp256k1::Error

Source

impl PartialOrd for Parity

Source

impl PartialOrd for TokenRegistry

Source

impl PartialOrd for Month

Source

impl PartialOrd for zerocopy::byteorder::BigEndian

Source

impl PartialOrd for zerocopy::byteorder::LittleEndian

1.0.0 (const: unstable) · Source

impl PartialOrd for bool

1.0.0 (const: unstable) · Source

impl PartialOrd for char

1.0.0 (const: unstable) · Source

impl PartialOrd for f16

1.0.0 (const: unstable) · Source

impl PartialOrd for f32

1.0.0 (const: unstable) · Source

impl PartialOrd for f64

1.0.0 (const: unstable) · Source

impl PartialOrd for f128

1.0.0 (const: unstable) · Source

impl PartialOrd for i8

1.0.0 (const: unstable) · Source

impl PartialOrd for i16

1.0.0 (const: unstable) · Source

impl PartialOrd for i32

1.0.0 (const: unstable) · Source

impl PartialOrd for i64

1.0.0 (const: unstable) · Source

impl PartialOrd for i128

1.0.0 (const: unstable) · Source

impl PartialOrd for isize

Source

impl PartialOrd for !

1.0.0 · Source

impl PartialOrd for str

Implements comparison operations on strings.

Strings are compared lexicographically by their byte values. This compares Unicode code points based on their positions in the code charts. This is not necessarily the same as “alphabetical” order, which varies by language and locale. Comparing strings according to culturally-accepted standards requires locale-specific data that is outside the scope of the str type.

1.0.0 (const: unstable) · Source

impl PartialOrd for u8

1.0.0 (const: unstable) · Source

impl PartialOrd for u16

1.0.0 (const: unstable) · Source

impl PartialOrd for u32

1.0.0 (const: unstable) · Source

impl PartialOrd for u64

1.0.0 (const: unstable) · Source

impl PartialOrd for u128

1.0.0 (const: unstable) · Source

impl PartialOrd for ()

1.0.0 (const: unstable) · Source

impl PartialOrd for usize

Source

impl PartialOrd for subsoil::application_crypto::ecdsa::AppPublic

Source

impl PartialOrd for subsoil::application_crypto::ed25519::AppPublic

Source

impl PartialOrd for subsoil::application_crypto::sr25519::AppPublic

Source

impl PartialOrd for BigUint

Source

impl PartialOrd for FixedI64

Source

impl PartialOrd for FixedI128

Source

impl PartialOrd for FixedU64

Source

impl PartialOrd for FixedU128

Source

impl PartialOrd for PerU16

Source

impl PartialOrd for Perbill

Source

impl PartialOrd for Percent

Source

impl PartialOrd for Permill

Source

impl PartialOrd for Perquintill

Source

impl PartialOrd for Rational128

Source

impl PartialOrd for RationalInfinite

Source

impl PartialOrd for subsoil::consensus::beefy::ecdsa_crypto::Public

Source

impl PartialOrd for Payload

Source

impl PartialOrd for SlotDuration

Source

impl PartialOrd for AccountId32

Source

impl PartialOrd for CryptoTypeId

Source

impl PartialOrd for KeyTypeId

Source

impl PartialOrd for Capabilities

Source

impl PartialOrd for subsoil::core::offchain::Duration

Source

impl PartialOrd for HttpRequestId

Source

impl PartialOrd for subsoil::core::offchain::Timestamp

Source

impl PartialOrd for subsoil::core::Bytes

Source

impl PartialOrd for H160

Source

impl PartialOrd for H256

Source

impl PartialOrd for H512

Source

impl PartialOrd for OpaquePeerId

Source

impl PartialOrd for U256

Source

impl PartialOrd for U512

Source

impl PartialOrd for ElectionScore

Source

impl PartialOrd for UintAuthorityId

Source

impl PartialOrd for OffenceSeverity

Source

impl PartialOrd for ChildTrieParentKeyId

Source

impl PartialOrd for PrefixedStorageKey

Source

impl PartialOrd for StorageData

Source

impl PartialOrd for StorageKey

Source

impl PartialOrd for TrackedStorageKey

Source

impl PartialOrd for subsoil::tracing::Level

1.0.0 · Source

impl PartialOrd for TypeId

1.0.0 · Source

impl PartialOrd for subsoil::std::fmt::Error

1.33.0 · Source

impl PartialOrd for PhantomPinned

Source

impl PartialOrd for Alignment

1.3.0 · Source

impl PartialOrd for subsoil::std::time::Duration

Source

impl PartialOrd for ByteString

1.64.0 · Source

impl PartialOrd for CString

1.0.0 · Source

impl PartialOrd for String

Source

impl PartialOrd for ByteStr

1.27.0 · Source

impl PartialOrd for CpuidResult

1.0.0 · Source

impl PartialOrd for CStr

1.0.0 · Source

impl PartialOrd for Ipv4Addr

1.0.0 · Source

impl PartialOrd for Ipv6Addr

1.0.0 · Source

impl PartialOrd for SocketAddrV4

1.0.0 · Source

impl PartialOrd for SocketAddrV6

1.10.0 · Source

impl PartialOrd for Location<'_>

1.0.0 · Source

impl PartialOrd for OsStr

1.0.0 · Source

impl PartialOrd for OsString

1.0.0 · Source

impl PartialOrd for std::path::Path

1.0.0 · Source

impl PartialOrd for PathBuf

1.8.0 · Source

impl PartialOrd for Instant

1.8.0 · Source

impl PartialOrd for SystemTime

Source

impl PartialOrd for aho_corasick::util::primitives::PatternID

Source

impl PartialOrd for aho_corasick::util::primitives::StateID

Source

impl PartialOrd for Mnemonic

Source

impl PartialOrd for bitcoin_hashes::hash160::Hash

Source

impl PartialOrd for bitcoin_hashes::ripemd160::Hash

Source

impl PartialOrd for bitcoin_hashes::sha1::Hash

Source

impl PartialOrd for bitcoin_hashes::sha256::Hash

Source

impl PartialOrd for Midstate

Source

impl PartialOrd for bitcoin_hashes::sha256d::Hash

Source

impl PartialOrd for bitcoin_hashes::sha384::Hash

Source

impl PartialOrd for bitcoin_hashes::sha512::Hash

Source

impl PartialOrd for bitcoin_hashes::sha512_256::Hash

Source

impl PartialOrd for bitcoin_hashes::siphash24::Hash

Source

impl PartialOrd for bytes::bytes::Bytes

Source

impl PartialOrd for BytesMut

Source

impl PartialOrd for ObjectIdentifier

Source

impl PartialOrd for VerificationKeyBytes

Source

impl PartialOrd for Register

Source

impl PartialOrd for DwAccess

Source

impl PartialOrd for DwAddr

Source

impl PartialOrd for DwAt

Source

impl PartialOrd for DwAte

Source

impl PartialOrd for DwCc

Source

impl PartialOrd for DwCfa

Source

impl PartialOrd for DwChildren

Source

impl PartialOrd for DwDefaulted

Source

impl PartialOrd for DwDs

Source

impl PartialOrd for DwDsc

Source

impl PartialOrd for DwEhPe

Source

impl PartialOrd for DwEnd

Source

impl PartialOrd for DwForm

Source

impl PartialOrd for DwId

Source

impl PartialOrd for DwIdx

Source

impl PartialOrd for DwInl

Source

impl PartialOrd for DwLang

Source

impl PartialOrd for DwLle

Source

impl PartialOrd for DwLnct

Source

impl PartialOrd for DwLne

Source

impl PartialOrd for DwLns

Source

impl PartialOrd for DwMacinfo

Source

impl PartialOrd for DwMacro

Source

impl PartialOrd for DwOp

Source

impl PartialOrd for DwOrd

Source

impl PartialOrd for DwRle

Source

impl PartialOrd for DwSect

Source

impl PartialOrd for DwSectV2

Source

impl PartialOrd for DwTag

Source

impl PartialOrd for DwUt

Source

impl PartialOrd for DwVirtuality

Source

impl PartialOrd for DwVis

Source

impl PartialOrd for ArangeEntry

Source

impl PartialOrd for Range

Source

impl PartialOrd for libsecp256k1_core::field::Field

Source

impl PartialOrd for H128

Source

impl PartialOrd for H384

Source

impl PartialOrd for H768

Source

impl PartialOrd for primitive_types::U128

Source

impl PartialOrd for LazyStateID

Source

impl PartialOrd for Unit

Source

impl PartialOrd for NonMaxUsize

Source

impl PartialOrd for regex_automata::util::primitives::PatternID

Source

impl PartialOrd for SmallIndex

Source

impl PartialOrd for regex_automata::util::primitives::StateID

Source

impl PartialOrd for regex_syntax::ast::Position

Source

impl PartialOrd for regex_syntax::ast::Position

Source

impl PartialOrd for regex_syntax::ast::Span

Source

impl PartialOrd for regex_syntax::ast::Span

Source

impl PartialOrd for regex_syntax::hir::literal::Literal

Source

impl PartialOrd for regex_syntax::hir::literal::Literal

Source

impl PartialOrd for regex_syntax::hir::ClassBytesRange

Source

impl PartialOrd for regex_syntax::hir::ClassBytesRange

Source

impl PartialOrd for regex_syntax::hir::ClassUnicodeRange

Source

impl PartialOrd for regex_syntax::hir::ClassUnicodeRange

Source

impl PartialOrd for regex_syntax::utf8::Utf8Range

Source

impl PartialOrd for regex_syntax::utf8::Utf8Range

Source

impl PartialOrd for MetaType

Source

impl PartialOrd for schnorrkel::keys::PublicKey

Source

impl PartialOrd for RistrettoBoth

Source

impl PartialOrd for VRFInOut

Source

impl PartialOrd for VRFPreOut

Source

impl PartialOrd for secp256k1_sys::recovery::RecoverableSignature

Available on non-secp256k1_fuzz only.
Source

impl PartialOrd for secp256k1_sys::ElligatorSwift

Source

impl PartialOrd for secp256k1_sys::Keypair

Available on non-secp256k1_fuzz only.
Source

impl PartialOrd for secp256k1_sys::PublicKey

Available on non-secp256k1_fuzz only.
Source

impl PartialOrd for secp256k1_sys::Signature

Available on non-secp256k1_fuzz only.
Source

impl PartialOrd for secp256k1_sys::XOnlyPublicKey

Available on non-secp256k1_fuzz only.
Source

impl PartialOrd for SharedSecret

Source

impl PartialOrd for secp256k1::ecdsa::recovery::RecoverableSignature

Source

impl PartialOrd for RecoveryId

Source

impl PartialOrd for SerializedSignature

Source

impl PartialOrd for secp256k1::ecdsa::Signature

Source

impl PartialOrd for secp256k1::ellswift::ElligatorSwift

Source

impl PartialOrd for ElligatorSwiftSharedSecret

Source

impl PartialOrd for InvalidParityValue

Source

impl PartialOrd for secp256k1::key::Keypair

Source

impl PartialOrd for secp256k1::key::PublicKey

Source

impl PartialOrd for secp256k1::key::XOnlyPublicKey

Source

impl PartialOrd for Scalar

Source

impl PartialOrd for secp256k1::schnorr::Signature

Source

impl PartialOrd for Message

Source

impl PartialOrd for Token

Source

impl PartialOrd for TokenAmount

Source

impl PartialOrd for Date

Source

impl PartialOrd for time::duration::Duration

Source

impl PartialOrd for OffsetDateTime

Source

impl PartialOrd for PrimitiveDateTime

Source

impl PartialOrd for Time

Source

impl PartialOrd for UtcDateTime

Source

impl PartialOrd for UtcOffset

Source

impl PartialOrd for tracing_core::metadata::LevelFilter

Source

impl PartialOrd for Directive

Source

impl PartialOrd for FmtSpan

Source

impl PartialOrd for trie_db::Bytes

Source

impl PartialOrd for ATerm

Source

impl PartialOrd for B0

Source

impl PartialOrd for B1

Source

impl PartialOrd for Z0

Source

impl PartialOrd for Equal

Source

impl PartialOrd for Greater

Source

impl PartialOrd for Less

Source

impl PartialOrd for UTerm

Source

impl PartialOrd<&ByteStr> for Cow<'_, str>

Source

impl PartialOrd<&ByteStr> for Cow<'_, ByteStr>

Source

impl PartialOrd<&ByteStr> for Cow<'_, [u8]>

Source

impl PartialOrd<&ByteStr> for ByteString

1.8.0 · Source

impl PartialOrd<&OsStr> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<&OsStr> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<&OsStr> for OsString

1.8.0 · Source

impl PartialOrd<&OsStr> for std::path::Path

1.8.0 · Source

impl PartialOrd<&OsStr> for PathBuf

1.8.0 · Source

impl PartialOrd<&Path> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<&Path> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<&Path> for OsStr

1.8.0 · Source

impl PartialOrd<&Path> for OsString

1.8.0 · Source

impl PartialOrd<&Path> for PathBuf

Source

impl PartialOrd<Cow<'_, str>> for &ByteStr

Source

impl PartialOrd<Cow<'_, str>> for ByteString

Source

impl PartialOrd<Cow<'_, ByteStr>> for &ByteStr

Source

impl PartialOrd<Cow<'_, ByteStr>> for ByteString

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for &OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for &std::path::Path

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for OsString

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for std::path::Path

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for PathBuf

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for &OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for &std::path::Path

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for OsString

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for std::path::Path

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for PathBuf

Source

impl PartialOrd<Cow<'_, [u8]>> for &ByteStr

Source

impl PartialOrd<Cow<'_, [u8]>> for ByteString

1.16.0 · Source

impl PartialOrd<IpAddr> for Ipv4Addr

1.16.0 · Source

impl PartialOrd<IpAddr> for Ipv6Addr

Source

impl PartialOrd<Level> for log::LevelFilter

Source

impl PartialOrd<LevelFilter> for log::Level

1.0.0 · Source

impl PartialOrd<str> for OsStr

1.0.0 · Source

impl PartialOrd<str> for OsString

Source

impl PartialOrd<str> for bytes::bytes::Bytes

Source

impl PartialOrd<str> for BytesMut

Source

impl PartialOrd<Level> for tracing_core::metadata::LevelFilter

Source

impl PartialOrd<Vec<u8>> for bytes::bytes::Bytes

Source

impl PartialOrd<Vec<u8>> for BytesMut

Source

impl PartialOrd<Duration> for time::duration::Duration

Source

impl PartialOrd<ByteString> for &ByteStr

Source

impl PartialOrd<ByteString> for Cow<'_, str>

Source

impl PartialOrd<ByteString> for Cow<'_, ByteStr>

Source

impl PartialOrd<ByteString> for Cow<'_, [u8]>

Source

impl PartialOrd<ByteString> for ByteStr

Source

impl PartialOrd<String> for bytes::bytes::Bytes

Source

impl PartialOrd<String> for BytesMut

Source

impl PartialOrd<ByteStr> for ByteString

1.16.0 · Source

impl PartialOrd<Ipv4Addr> for IpAddr

1.16.0 · Source

impl PartialOrd<Ipv6Addr> for IpAddr

1.8.0 · Source

impl PartialOrd<OsStr> for &std::path::Path

1.8.0 · Source

impl PartialOrd<OsStr> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<OsStr> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<OsStr> for OsString

1.8.0 · Source

impl PartialOrd<OsStr> for std::path::Path

1.8.0 · Source

impl PartialOrd<OsStr> for PathBuf

1.8.0 · Source

impl PartialOrd<OsString> for &OsStr

1.8.0 · Source

impl PartialOrd<OsString> for &std::path::Path

1.8.0 · Source

impl PartialOrd<OsString> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<OsString> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<OsString> for OsStr

1.8.0 · Source

impl PartialOrd<OsString> for std::path::Path

1.8.0 · Source

impl PartialOrd<OsString> for PathBuf

1.8.0 · Source

impl PartialOrd<Path> for &OsStr

1.8.0 · Source

impl PartialOrd<Path> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<Path> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<Path> for OsStr

1.8.0 · Source

impl PartialOrd<Path> for OsString

1.8.0 · Source

impl PartialOrd<Path> for PathBuf

1.8.0 · Source

impl PartialOrd<PathBuf> for &OsStr

1.8.0 · Source

impl PartialOrd<PathBuf> for &std::path::Path

1.8.0 · Source

impl PartialOrd<PathBuf> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<PathBuf> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<PathBuf> for OsStr

1.8.0 · Source

impl PartialOrd<PathBuf> for OsString

1.8.0 · Source

impl PartialOrd<PathBuf> for std::path::Path

Source

impl PartialOrd<SystemTime> for OffsetDateTime

Source

impl PartialOrd<SystemTime> for UtcDateTime

Source

impl PartialOrd<Bytes> for &str

Source

impl PartialOrd<Bytes> for &[u8]

Source

impl PartialOrd<Bytes> for str

Source

impl PartialOrd<Bytes> for subsoil::std::prelude::Vec<u8>

Source

impl PartialOrd<Bytes> for String

Source

impl PartialOrd<Bytes> for [u8]

Source

impl PartialOrd<BytesMut> for &str

Source

impl PartialOrd<BytesMut> for &[u8]

Source

impl PartialOrd<BytesMut> for str

Source

impl PartialOrd<BytesMut> for subsoil::std::prelude::Vec<u8>

Source

impl PartialOrd<BytesMut> for String

Source

impl PartialOrd<BytesMut> for [u8]

Source

impl PartialOrd<SerializedSignature> for [u8]

Source

impl PartialOrd<Duration> for subsoil::std::time::Duration

Source

impl PartialOrd<OffsetDateTime> for SystemTime

Source

impl PartialOrd<OffsetDateTime> for UtcDateTime

Source

impl PartialOrd<UtcDateTime> for SystemTime

Source

impl PartialOrd<UtcDateTime> for OffsetDateTime

Source

impl PartialOrd<LevelFilter> for subsoil::tracing::Level

Source

impl PartialOrd<[u8]> for bytes::bytes::Bytes

Source

impl PartialOrd<[u8]> for BytesMut

Source

impl PartialOrd<[u8]> for SerializedSignature

Source

impl<'a> PartialOrd for OpaqueDigestItemId<'a>

1.0.0 · Source

impl<'a> PartialOrd for Component<'a>

1.0.0 · Source

impl<'a> PartialOrd for Prefix<'a>

Source

impl<'a> PartialOrd for PhantomContravariantLifetime<'a>

Source

impl<'a> PartialOrd for PhantomCovariantLifetime<'a>

Source

impl<'a> PartialOrd for PhantomInvariantLifetime<'a>

1.0.0 · Source

impl<'a> PartialOrd for Components<'a>

1.0.0 · Source

impl<'a> PartialOrd for PrefixComponent<'a>

Source

impl<'a> PartialOrd for Metadata<'a>

Source

impl<'a> PartialOrd for MetadataBuilder<'a>

Source

impl<'a> PartialOrd for DecimalStr<'a>

Source

impl<'a> PartialOrd for InfinityStr<'a>

Source

impl<'a> PartialOrd for MinusSignStr<'a>

Source

impl<'a> PartialOrd for NanStr<'a>

Source

impl<'a> PartialOrd for PlusSignStr<'a>

Source

impl<'a> PartialOrd for SeparatorStr<'a>

Source

impl<'a> PartialOrd for NibbleSlice<'a>

1.0.0 · Source

impl<'a, B> PartialOrd for Cow<'a, B>
where B: PartialOrd + ToOwned + ?Sized,

Source

impl<'a, T> PartialOrd for Symbol<'a, T>
where T: PartialOrd + 'a,

Source

impl<'a, T> PartialOrd<&'a T> for bytes::bytes::Bytes
where Bytes: PartialOrd<T>, T: ?Sized,

Source

impl<'a, T> PartialOrd<&'a T> for BytesMut
where BytesMut: PartialOrd<T>, T: ?Sized,

Source

impl<'a, T, BoundSelf, BoundRhs> PartialOrd<BoundedSlice<'a, T, BoundRhs>> for BoundedSlice<'a, T, BoundSelf>
where T: PartialOrd, BoundSelf: Get<u32>, BoundRhs: Get<u32>,

Source

impl<'a, T, BoundSelf, BoundRhs> PartialOrd<BoundedSlice<'a, T, BoundRhs>> for BoundedVec<T, BoundSelf>
where T: PartialOrd, BoundSelf: Get<u32>, BoundRhs: Get<u32>,

Source

impl<'a, T, BoundSelf, BoundRhs> PartialOrd<BoundedSlice<'a, T, BoundRhs>> for WeakBoundedVec<T, BoundSelf>
where T: PartialOrd, BoundSelf: Get<u32>, BoundRhs: Get<u32>,

Source

impl<'a, T, BoundSelf, BoundRhs> PartialOrd<BoundedVec<T, BoundRhs>> for BoundedSlice<'a, T, BoundSelf>
where T: PartialOrd, BoundSelf: Get<u32>, BoundRhs: Get<u32>,

Source

impl<'a, T, BoundSelf, BoundRhs> PartialOrd<WeakBoundedVec<T, BoundRhs>> for BoundedSlice<'a, T, BoundSelf>
where T: PartialOrd, BoundSelf: Get<u32>, BoundRhs: Get<u32>,

Source

impl<'buf> PartialOrd for AllPreallocated<'buf>

Source

impl<'buf> PartialOrd for SignOnlyPreallocated<'buf>

Source

impl<'buf> PartialOrd for VerifyOnlyPreallocated<'buf>

Source

impl<'s, T> PartialOrd for SliceVec<'s, T>
where T: PartialOrd,

Source

impl<A> PartialOrd for TinyVec<A>
where A: Array, <A as Array>::Item: PartialOrd,

Source

impl<A> PartialOrd for SmallVec<A>
where A: Array, <A as Array>::Item: PartialOrd,

Source

impl<A> PartialOrd for tinyvec::arrayvec::ArrayVec<A>
where A: Array, <A as Array>::Item: PartialOrd,

1.0.0 (const: unstable) · Source

impl<A, B> PartialOrd<&B> for &A
where A: PartialOrd<B> + ?Sized, B: ?Sized,

1.0.0 (const: unstable) · Source

impl<A, B> PartialOrd<&mut B> for &mut A
where A: PartialOrd<B> + ?Sized, B: ?Sized,

Source

impl<AccountId: PartialOrd, Balance: PartialOrd + HasCompact> PartialOrd for Exposure<AccountId, Balance>

Source

impl<AccountId: PartialOrd, Balance: PartialOrd + HasCompact> PartialOrd for ExposurePage<AccountId, Balance>

Source

impl<AccountId: PartialOrd, Balance: PartialOrd + HasCompact> PartialOrd for IndividualExposure<AccountId, Balance>

Source

impl<Balance: PartialOrd + HasCompact + MaxEncodedLen> PartialOrd for PagedExposureMetadata<Balance>

Source

impl<Dyn> PartialOrd for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<E> PartialOrd for I16Bytes<E>
where E: PartialOrd + Endian,

Source

impl<E> PartialOrd for I32Bytes<E>
where E: PartialOrd + Endian,

Source

impl<E> PartialOrd for I64Bytes<E>
where E: PartialOrd + Endian,

Source

impl<E> PartialOrd for U16Bytes<E>
where E: PartialOrd + Endian,

Source

impl<E> PartialOrd for U32Bytes<E>
where E: PartialOrd + Endian,

Source

impl<E> PartialOrd for U64Bytes<E>
where E: PartialOrd + Endian,

1.4.0 · Source

impl<F> PartialOrd for F
where F: FnPtr,

1.0.0 · Source

impl<K, V, A> PartialOrd for BTreeMap<K, V, A>
where K: PartialOrd, V: PartialOrd, A: Allocator + Clone,

Source

impl<K, V, S> PartialOrd for BoundedBTreeMap<K, V, S>
where BTreeMap<K, V>: PartialOrd, S: Get<u32>,

Source

impl<L, R> PartialOrd for Either<L, R>
where L: PartialOrd, R: PartialOrd,

Source

impl<O> PartialOrd for F32<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for F64<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for I16<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for I32<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for I64<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for I128<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for Isize<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for U16<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for U32<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for U64<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for zerocopy::byteorder::U128<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for Usize<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<i16> for I16<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<i32> for I32<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<i64> for I64<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<i128> for I128<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<isize> for Isize<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<u16> for U16<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<u32> for U32<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<u64> for U64<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<u128> for zerocopy::byteorder::U128<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<usize> for Usize<O>
where O: ByteOrder,

1.41.0 · Source

impl<Ptr, Q> PartialOrd<Pin<Q>> for Pin<Ptr>
where Ptr: Deref, Q: Deref, <Ptr as Deref>::Target: PartialOrd<<Q as Deref>::Target>,

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for Option<T>
where T: PartialOrd,

1.36.0 · Source

impl<T> PartialOrd for Poll<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for UnitSectionOffset<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for TypeDef<T>
where T: PartialOrd + Form,

1.0.0 · Source

impl<T> PartialOrd for *const T
where T: ?Sized,

Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.

1.0.0 · Source

impl<T> PartialOrd for *mut T
where T: ?Sized,

Pointer comparison is by address, as produced by the <*mut T>::addr method.

1.0.0 · Source

impl<T> PartialOrd for [T]
where T: PartialOrd,

Implements comparison of slices lexicographically.

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for (T₁, T₂, …, Tₙ)
where T: PartialOrd,

This trait is implemented for tuples up to twelve items long.

1.10.0 · Source

impl<T> PartialOrd for Cell<T>
where T: PartialOrd + Copy,

1.10.0 · Source

impl<T> PartialOrd for RefCell<T>
where T: PartialOrd + ?Sized,

Source

impl<T> PartialOrd for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> PartialOrd for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> PartialOrd for PhantomData<T>
where T: ?Sized,

Source

impl<T> PartialOrd for PhantomInvariant<T>
where T: ?Sized,

1.20.0 · Source

impl<T> PartialOrd for ManuallyDrop<T>
where T: PartialOrd + ?Sized,

1.28.0 (const: unstable) · Source

impl<T> PartialOrd for NonZero<T>

1.74.0 · Source

impl<T> PartialOrd for Saturating<T>
where T: PartialOrd,

1.0.0 · Source

impl<T> PartialOrd for Wrapping<T>
where T: PartialOrd,

1.19.0 (const: unstable) · Source

impl<T> PartialOrd for Reverse<T>
where T: PartialOrd,

1.25.0 · Source

impl<T> PartialOrd for NonNull<T>
where T: ?Sized,

Source

impl<T> PartialOrd for CapacityError<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for Hmac<T>
where T: PartialOrd + Hash,

Source

impl<T> PartialOrd for bitcoin_hashes::sha256t::Hash<T>
where T: Tag,

Source

impl<T> PartialOrd for AllowStdIo<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for DebugInfoOffset<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for DebugTypesOffset<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for UnitOffset<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for jam_codec::compact::Compact<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for parity_scale_codec::compact::Compact<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for UntrackedSymbol<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for TypeDefComposite<T>
where T: PartialOrd + Form,

Source

impl<T> PartialOrd for scale_info::ty::fields::Field<T>
where T: PartialOrd + Form, <T as Form>::String: PartialOrd, <T as Form>::Type: PartialOrd,

Source

impl<T> PartialOrd for scale_info::ty::path::Path<T>
where T: PartialOrd + Form, <T as Form>::String: PartialOrd,

Source

impl<T> PartialOrd for Type<T>
where T: PartialOrd + Form, <T as Form>::String: PartialOrd,

Source

impl<T> PartialOrd for TypeDefArray<T>
where T: PartialOrd + Form, <T as Form>::Type: PartialOrd,

Source

impl<T> PartialOrd for TypeDefBitSequence<T>
where T: PartialOrd + Form, <T as Form>::Type: PartialOrd,

Source

impl<T> PartialOrd for TypeDefCompact<T>
where T: PartialOrd + Form, <T as Form>::Type: PartialOrd,

Source

impl<T> PartialOrd for TypeDefSequence<T>
where T: PartialOrd + Form, <T as Form>::Type: PartialOrd,

Source

impl<T> PartialOrd for TypeDefTuple<T>
where T: PartialOrd + Form, <T as Form>::Type: PartialOrd,

Source

impl<T> PartialOrd for TypeParameter<T>
where T: PartialOrd + Form, <T as Form>::String: PartialOrd, <T as Form>::Type: PartialOrd,

Source

impl<T> PartialOrd for TypeDefVariant<T>
where T: PartialOrd + Form,

Source

impl<T> PartialOrd for Variant<T>
where T: PartialOrd + Form, <T as Form>::String: PartialOrd,

Source

impl<T> PartialOrd for Unalign<T>
where T: Unaligned + PartialOrd,

1.0.0 · Source

impl<T, A1, A2> PartialOrd<Vec<T, A2>> for subsoil::std::prelude::Vec<T, A1>
where T: PartialOrd, A1: Allocator, A2: Allocator,

Implements comparison of vectors, lexicographically.

1.0.0 · Source

impl<T, A> PartialOrd for BTreeSet<T, A>
where T: PartialOrd, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> PartialOrd for VecDeque<T, A>
where T: PartialOrd, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for subsoil::std::prelude::Box<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for Rc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for UniqueRc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for Arc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for UniqueArc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for LinkedList<T, A>
where T: PartialOrd, A: Allocator,

Source

impl<T, A> PartialOrd for allocator_api2::stable::boxed::Box<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for allocator_api2::stable::vec::Vec<T, A>
where T: PartialOrd, A: Allocator,

Implements comparison of vectors, lexicographically.

Source

impl<T, B> PartialOrd for Ref<B, T>

Source

impl<T, BoundSelf, BoundRhs> PartialOrd<BoundedVec<T, BoundRhs>> for BoundedVec<T, BoundSelf>
where T: PartialOrd, BoundSelf: Get<u32>, BoundRhs: Get<u32>,

Source

impl<T, BoundSelf, BoundRhs> PartialOrd<BoundedVec<T, BoundRhs>> for WeakBoundedVec<T, BoundSelf>
where T: PartialOrd, BoundSelf: Get<u32>, BoundRhs: Get<u32>,

Source

impl<T, BoundSelf, BoundRhs> PartialOrd<WeakBoundedVec<T, BoundRhs>> for BoundedVec<T, BoundSelf>
where T: PartialOrd, BoundSelf: Get<u32>, BoundRhs: Get<u32>,

Source

impl<T, BoundSelf, BoundRhs> PartialOrd<WeakBoundedVec<T, BoundRhs>> for WeakBoundedVec<T, BoundSelf>
where T: PartialOrd, BoundSelf: Get<u32>, BoundRhs: Get<u32>,

1.0.0 (const: unstable) · Source

impl<T, E> PartialOrd for Result<T, E>
where T: PartialOrd, E: PartialOrd,

Source

impl<T, N> PartialOrd for GenericArray<T, N>
where T: PartialOrd, N: ArrayLength<T>,

Source

impl<T, S> PartialOrd for BoundedBTreeSet<T, S>
where BTreeSet<T>: PartialOrd, S: Get<u32>,

Source

impl<T, U> PartialOrd<Exclusive<U>> for Exclusive<T>
where T: Sync + PartialOrd<U> + ?Sized, U: Sync + ?Sized,

Source

impl<T, const CAP: usize> PartialOrd for arrayvec::arrayvec::ArrayVec<T, CAP>
where T: PartialOrd,

1.0.0 · Source

impl<T, const N: usize> PartialOrd for [T; N]
where T: PartialOrd,

Implements comparison of arrays lexicographically.

Source

impl<T, const N: usize> PartialOrd for Mask<T, N>

Source

impl<T, const N: usize> PartialOrd for Simd<T, N>

Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.

Source

impl<T: Into<u64> + Copy> PartialOrd<T> for Slot

Source

impl<T: Into<u64> + Copy> PartialOrd<T> for subsoil::timestamp::Timestamp

Source

impl<T: PartialOrd, D: Get<T>> PartialOrd for TypeWithDefault<T, D>

Source

impl<TBlockNumber> PartialOrd for Commitment<TBlockNumber>
where TBlockNumber: Ord,

Source

impl<U> PartialOrd for NInt<U>

Source

impl<U> PartialOrd for PInt<U>

Source

impl<U, B> PartialOrd for UInt<U, B>
where U: PartialOrd, B: PartialOrd,

Source

impl<V, A> PartialOrd for TArr<V, A>
where V: PartialOrd, A: PartialOrd,

Source

impl<Y, R> PartialOrd for CoroutineState<Y, R>
where Y: PartialOrd, R: PartialOrd,

Source

impl<const CAP: usize> PartialOrd for ArrayString<CAP>

Source

impl<const CAP: usize> PartialOrd<str> for ArrayString<CAP>

Source

impl<const CAP: usize> PartialOrd<ArrayString<CAP>> for str

Source

impl<const LEFT_SIZE: usize, const RIGHT_SIZE: usize> PartialOrd<WriteBuffer<RIGHT_SIZE>> for WriteBuffer<LEFT_SIZE>

Source

impl<const MIN_A: i8, const MAX_A: i8, const MIN_B: i8, const MAX_B: i8> PartialOrd<OptionRangedI8<MIN_B, MAX_B>> for OptionRangedI8<MIN_A, MAX_A>

Source

impl<const MIN_A: i8, const MAX_A: i8, const MIN_B: i8, const MAX_B: i8> PartialOrd<RangedI8<MIN_B, MAX_B>> for RangedI8<MIN_A, MAX_A>

Source

impl<const MIN_A: i16, const MAX_A: i16, const MIN_B: i16, const MAX_B: i16> PartialOrd<OptionRangedI16<MIN_B, MAX_B>> for OptionRangedI16<MIN_A, MAX_A>

Source

impl<const MIN_A: i16, const MAX_A: i16, const MIN_B: i16, const MAX_B: i16> PartialOrd<RangedI16<MIN_B, MAX_B>> for RangedI16<MIN_A, MAX_A>

Source

impl<const MIN_A: i32, const MAX_A: i32, const MIN_B: i32, const MAX_B: i32> PartialOrd<OptionRangedI32<MIN_B, MAX_B>> for OptionRangedI32<MIN_A, MAX_A>

Source

impl<const MIN_A: i32, const MAX_A: i32, const MIN_B: i32, const MAX_B: i32> PartialOrd<RangedI32<MIN_B, MAX_B>> for RangedI32<MIN_A, MAX_A>

Source

impl<const MIN_A: i64, const MAX_A: i64, const MIN_B: i64, const MAX_B: i64> PartialOrd<OptionRangedI64<MIN_B, MAX_B>> for OptionRangedI64<MIN_A, MAX_A>

Source

impl<const MIN_A: i64, const MAX_A: i64, const MIN_B: i64, const MAX_B: i64> PartialOrd<RangedI64<MIN_B, MAX_B>> for RangedI64<MIN_A, MAX_A>

Source

impl<const MIN_A: i128, const MAX_A: i128, const MIN_B: i128, const MAX_B: i128> PartialOrd<OptionRangedI128<MIN_B, MAX_B>> for OptionRangedI128<MIN_A, MAX_A>

Source

impl<const MIN_A: i128, const MAX_A: i128, const MIN_B: i128, const MAX_B: i128> PartialOrd<RangedI128<MIN_B, MAX_B>> for RangedI128<MIN_A, MAX_A>

Source

impl<const MIN_A: isize, const MAX_A: isize, const MIN_B: isize, const MAX_B: isize> PartialOrd<OptionRangedIsize<MIN_B, MAX_B>> for OptionRangedIsize<MIN_A, MAX_A>

Source

impl<const MIN_A: isize, const MAX_A: isize, const MIN_B: isize, const MAX_B: isize> PartialOrd<RangedIsize<MIN_B, MAX_B>> for RangedIsize<MIN_A, MAX_A>

Source

impl<const MIN_A: u8, const MAX_A: u8, const MIN_B: u8, const MAX_B: u8> PartialOrd<OptionRangedU8<MIN_B, MAX_B>> for OptionRangedU8<MIN_A, MAX_A>

Source

impl<const MIN_A: u8, const MAX_A: u8, const MIN_B: u8, const MAX_B: u8> PartialOrd<RangedU8<MIN_B, MAX_B>> for RangedU8<MIN_A, MAX_A>

Source

impl<const MIN_A: u16, const MAX_A: u16, const MIN_B: u16, const MAX_B: u16> PartialOrd<OptionRangedU16<MIN_B, MAX_B>> for OptionRangedU16<MIN_A, MAX_A>

Source

impl<const MIN_A: u16, const MAX_A: u16, const MIN_B: u16, const MAX_B: u16> PartialOrd<RangedU16<MIN_B, MAX_B>> for RangedU16<MIN_A, MAX_A>

Source

impl<const MIN_A: u32, const MAX_A: u32, const MIN_B: u32, const MAX_B: u32> PartialOrd<OptionRangedU32<MIN_B, MAX_B>> for OptionRangedU32<MIN_A, MAX_A>

Source

impl<const MIN_A: u32, const MAX_A: u32, const MIN_B: u32, const MAX_B: u32> PartialOrd<RangedU32<MIN_B, MAX_B>> for RangedU32<MIN_A, MAX_A>

Source

impl<const MIN_A: u64, const MAX_A: u64, const MIN_B: u64, const MAX_B: u64> PartialOrd<OptionRangedU64<MIN_B, MAX_B>> for OptionRangedU64<MIN_A, MAX_A>

Source

impl<const MIN_A: u64, const MAX_A: u64, const MIN_B: u64, const MAX_B: u64> PartialOrd<RangedU64<MIN_B, MAX_B>> for RangedU64<MIN_A, MAX_A>

Source

impl<const MIN_A: u128, const MAX_A: u128, const MIN_B: u128, const MAX_B: u128> PartialOrd<OptionRangedU128<MIN_B, MAX_B>> for OptionRangedU128<MIN_A, MAX_A>

Source

impl<const MIN_A: u128, const MAX_A: u128, const MIN_B: u128, const MAX_B: u128> PartialOrd<RangedU128<MIN_B, MAX_B>> for RangedU128<MIN_A, MAX_A>

Source

impl<const MIN_A: usize, const MAX_A: usize, const MIN_B: usize, const MAX_B: usize> PartialOrd<OptionRangedUsize<MIN_B, MAX_B>> for OptionRangedUsize<MIN_A, MAX_A>

Source

impl<const MIN_A: usize, const MAX_A: usize, const MIN_B: usize, const MAX_B: usize> PartialOrd<RangedUsize<MIN_B, MAX_B>> for RangedUsize<MIN_A, MAX_A>

Source

impl<const N: usize, T> PartialOrd for CryptoBytes<N, T>